MorphingButtonThemeData class

Constructors

MorphingButtonThemeData({Color? accentColor, Color? textColor, double? fontSize, double? letterSpacing, double? horizontalPadding, double? verticalPadding, double? arrowSize, double? arrowStrokeWidth})
const

Properties

accentColor Color?
final
arrowSize double?
final
arrowStrokeWidth double?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setteroverride
horizontalPadding double?
final
letterSpacing double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
final
verticalPadding double?
final

Methods

merge(MorphingButtonThemeData? other) MorphingButtonThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override